@@ -20,6 +20,8 @@ import os
 
 import pytest
 
+from utils import assert_equal, assert_not_equal
+
 from nacl.bindings import crypto_sign_PUBLICKEYBYTES, crypto_sign_SEEDBYTES
 from nacl.encoding import HexEncoder
 from nacl.exceptions import BadSignatureError
@@ -63,6 +65,27 @@ class TestSigningKey:
         k = SigningKey(b"\x00" * crypto_sign_SEEDBYTES)
         assert bytes(k) == b"\x00" * crypto_sign_SEEDBYTES
 
+    def test_equal_keys_are_equal(self):
+        k1 = SigningKey(b"\x00" * crypto_sign_SEEDBYTES)
+        k2 = SigningKey(b"\x00" * crypto_sign_SEEDBYTES)
+        assert_equal(k1, k1)
+        assert_equal(k1, k2)
+
+    def test_equal_keys_have_equal_hashes(self):
+        k1 = SigningKey(b"\x00" * crypto_sign_SEEDBYTES)
+        k2 = SigningKey(b"\x00" * crypto_sign_SEEDBYTES)
+        assert hash(k1) == hash(k2)
+        assert id(k1) != id(k2)
+
+    @pytest.mark.parametrize('k2', [
+        b"\x00" * crypto_sign_SEEDBYTES,
+        SigningKey(b"\x01" * crypto_sign_SEEDBYTES),
+        SigningKey(b"\x00" * (crypto_sign_SEEDBYTES - 1) + b"\x01"),
+    ])
+    def test_different_keys_are_not_equal(self, k2):
+        k1 = SigningKey(b"\x00" * crypto_sign_SEEDBYTES)
+        assert_not_equal(k1, k2)
+
     @pytest.mark.parametrize("seed", [
         b"77076d0a7318a57d3c16c17251b26645df4c2f87ebc0992ab177fba51db92c2a",
     ])
@@ -100,6 +123,27 @@ class TestVerifyKey:
         k = VerifyKey(b"\x00" * crypto_sign_PUBLICKEYBYTES)
         assert bytes(k) == b"\x00" * crypto_sign_PUBLICKEYBYTES
 
+    def test_equal_keys_are_equal(self):
+        k1 = VerifyKey(b"\x00" * crypto_sign_PUBLICKEYBYTES)
+        k2 = VerifyKey(b"\x00" * crypto_sign_PUBLICKEYBYTES)
+        assert_equal(k1, k1)
+        assert_equal(k1, k2)
+
+    def test_equal_keys_have_equal_hashes(self):
+        k1 = VerifyKey(b"\x00" * crypto_sign_PUBLICKEYBYTES)
+        k2 = VerifyKey(b"\x00" * crypto_sign_PUBLICKEYBYTES)
+        assert hash(k1) == hash(k2)
+        assert id(k1) != id(k2)
+
+    @pytest.mark.parametrize('k2', [
+        b"\x00" * crypto_sign_PUBLICKEYBYTES,
+        VerifyKey(b"\x01" * crypto_sign_PUBLICKEYBYTES),
+        VerifyKey(b"\x00" * (crypto_sign_PUBLICKEYBYTES - 1) + b"\x01"),
+    ])
+    def test_different_keys_are_not_equal(self, k2):
+        k1 = VerifyKey(b"\x00" * crypto_sign_PUBLICKEYBYTES)
+        assert_not_equal(k1, k2)
+
     @pytest.mark.parametrize(
         ("public_key", "signed", "message", "signature"),
         [
